Package: billboarder
Title: Create Interactive Chart with the JavaScript 'Billboard' Library
Version: 0.4.1
Authors@R: c(
  person("Victor", "Perrier", email = "victor.perrier@dreamrs.fr", role = c("aut", "cre")),
  person("Fanny", "Meyer", role = "aut"),
  person("NAVER Corp", role = "cph", comment = "billboard.js library"),
  person("Mike", "Bostock", role = "cph", comment = "d3.format library"))
Description: Provides an 'htmlwidgets' interface to 'billboard.js', 
    a re-usable easy interface JavaScript chart library, based on D3 v4+.
    Chart types include line charts, scatterplots, bar/lollipop charts, histogram/density plots, pie/donut charts and gauge charts.
    All charts are interactive, and a proxy method is implemented to smoothly update a chart without rendering it again in 'shiny' apps. 
URL: https://github.com/dreamRs/billboarder,
        https://dreamrs.github.io/billboarder/
BugReports: https://github.com/dreamRs/billboarder/issues
Depends: R (>= 3.1.0)
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.3
Imports: htmlwidgets, htmltools, magrittr, jsonlite, ggplot2, scales,
        shiny, rlang
Suggests: RColorBrewer, testthat, knitr, rmarkdown, covr
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2023-09-29 13:40:27 UTC; perri
Author: Victor Perrier [aut, cre],
  Fanny Meyer [aut],
  NAVER Corp [cph] (billboard.js library),
  Mike Bostock [cph] (d3.format library)
Maintainer: Victor Perrier <victor.perrier@dreamrs.fr>
Repository: CRAN
Date/Publication: 2023-09-29 14:02:38 UTC
Built: R 4.2.0; ; 2023-09-29 14:40:27 UTC; unix
