# Generated by roxygen2: do not edit by hand

export("%>%")
export(JS)
export(aes)
export(bauge)
export(baugeOutput)
export(bb_add_style)
export(bb_aes)
export(bb_aes_string)
export(bb_area)
export(bb_axis)
export(bb_bar)
export(bb_bar_color_manual)
export(bb_barchart)
export(bb_bubble)
export(bb_callbacks)
export(bb_categories)
export(bb_color)
export(bb_colors_manual)
export(bb_data)
export(bb_densityplot)
export(bb_donut)
export(bb_donutchart)
export(bb_export)
export(bb_gauge)
export(bb_gaugechart)
export(bb_grid)
export(bb_histogram)
export(bb_interaction)
export(bb_labs)
export(bb_legend)
export(bb_line)
export(bb_linechart)
export(bb_load)
export(bb_lollipop)
export(bb_pie)
export(bb_piechart)
export(bb_point)
export(bb_proxy_axis_labels)
export(bb_proxy_data_colors)
export(bb_proxy_data_names)
export(bb_proxy_defocus)
export(bb_proxy_flow)
export(bb_proxy_focus)
export(bb_proxy_groups)
export(bb_proxy_hide)
export(bb_proxy_legend)
export(bb_proxy_show)
export(bb_proxy_tooltip)
export(bb_proxy_transform)
export(bb_proxy_xs)
export(bb_radar)
export(bb_radarchart)
export(bb_regions)
export(bb_render)
export(bb_scatterplot)
export(bb_spline)
export(bb_subchart)
export(bb_svg)
export(bb_title)
export(bb_tooltip)
export(bb_transition)
export(bb_treemap)
export(bb_treemapchart)
export(bb_unload)
export(bb_x_axis)
export(bb_x_grid)
export(bb_y_axis)
export(bb_y_grid)
export(bb_zoom)
export(bbaes)
export(bbaes_string)
export(billboarder)
export(billboarderOutput)
export(billboarderProxy)
export(prefix)
export(proxy_example)
export(renderBauge)
export(renderBillboarder)
export(set_color_palette)
export(set_theme)
export(suffix)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,layer_data)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,tags)
importFrom(htmlwidgets,JS)
importFrom(htmlwidgets,createWidget)
importFrom(htmlwidgets,shinyRenderWidget)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(htmlwidgets,sizingPolicy)
importFrom(jsonlite,toJSON)
importFrom(magrittr,"%>%")
importFrom(rlang,as_label)
importFrom(rlang,eval_tidy)
importFrom(scales,rescale)
importFrom(shiny,shinyAppDir)
importFrom(stats,density)
importFrom(stats,density.default)
importFrom(stats,reshape)
importFrom(stats,setNames)
importFrom(utils,modifyList)
